flextrix library
Classes
- AdaptiveBuilder
-
BaseLayoutValue<
T> - BoostrapLayoutFormat
-
BreakpointValue<
T> - A responsive value that adapts dynamically dinamically to relative width screen breakpoints
-
ConstantLayoutValue<
T> - FluidLayoutFormat
- FluidMargin
- A widget that adds a fluid padding to its child. This padding has the goal to constrain the child to a given max width according to the screen size
- Gap
- A widget that takes a fixed amount of space in the direction of its parent.
- Gutter
- Layout
- A widget that generates the responsive layout data for its children.
- LayoutContext
- LayoutData
-
LayoutValue<
T> - A responsive value that adapts dynamically to the width of the screen.
- Margin
-
A widget that adds a padding to its child. This
padding is calculated by
Layoutand can be overrided by the margin param - MaterialLayoutFormat
- MaxGap
- A widget that takes, at most, an amount of space in a Row, Column, or Flex widget.
- SliverFluidBox
- SliverFluidMargin
- Equivalent of FluidMargin for sliver widgets
- SliverGap
- A sliver that takes a fixed amount of space.
- SliverGutter
- SliverMargin
-
A widget that adds a padding to its sliver child. This
padding is calculated by
Layoutand can be overrided by the margin param
Enums
Mixins
Extensions
Typedefs
-
LayoutValueBuilder<
T> = T Function(LayoutContext layout) - LayoutWidgetBuilder = Widget Function(BuildContext context, LayoutContext layout, Widget? child)